=======================
Behavioral Cloning (BC)
=======================

Supervised learning on observation-action pairs.

API
===
.. autoclass:: imitation.algorithms.bc.BC
    :members:
    :noindex:
